
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: ContribPlugin(BuildFileAddress(BuildFile(contrib/scrooge/src/python/pants/contrib/scrooge/BUILD, FileSystemProjectTree(/Users/stuhood/src/pants)), plugin))

from setuptools import setup

setup(**
{   'classifiers': [   'Intended Audience :: Developers',
                       'License :: OSI Approved :: Apache Software License',
                       'Operating System :: MacOS :: MacOS X',
                       'Operating System :: POSIX :: Linux',
                       'Programming Language :: Python',
                       'Topic :: Software Development :: Build Tools',
                       'Topic :: Software Development :: Code Generators'],
    'description': 'Scrooge thrift generator pants plugins.',
    'entry_points': {   'pantsbuild.plugin': [   'register_goals = pants.contrib.scrooge.register:register_goals']},
    'install_requires': [   'twitter.common.collections>=0.3.1,<0.4',
                            'pantsbuild.pants==1.2.0rc2'],
    'license': 'Apache License, Version 2.0',
    'long_description': 'Pants is an Apache2 licensed build tool written in Python.\n\nThe latest documentation can be found `here <http://pantsbuild.github.io/>`_.\n\n1.2.x Stable Releases\n=====================\n\nThis document describes releases from the ``1.2.x`` ``stable`` branch.\n\n\n1.2.0rc2 (10/18/2016)\n---------------------\n\nThe third, and perhaps final, release candidate for stable 1.2.0.\n\nNotably: this release candidate restores JDK7 compatibility for junit tests.\n\nAPI Changes\n~~~~~~~~~~~\n\n* Update junit runner to 1.0.15 to get java 7 compatibility\n  `RB #4324 <https://rbcommons.com/s/twitter/r/4324>`_\n\n* Back down the minimum required java version for running Pants tools to java 7\n  `RB #4314 <https://rbcommons.com/s/twitter/r/4314>`_\n\nBugfixes\n~~~~~~~~\n\n* Fix exclude_target_regexp breakage in test-changed and --files option breakage in changed with diffspec\n  `RB #4321 <https://rbcommons.com/s/twitter/r/4321>`_\n\n* Prevent cleanup error at end of pants test with --test-junit-html-report option, update safe_rmtree to be symlink aware\n  `RB #4319 <https://rbcommons.com/s/twitter/r/4319>`_\n\n* fix --changed-files option\n  `RB #4309 <https://rbcommons.com/s/twitter/r/4309>`_\n\nNew Features\n~~~~~~~~~~~~\n\n* Adding scalafmt formatting to fmt goal and enable by default\n  `RB #4312 <https://rbcommons.com/s/twitter/r/4312>`_\n\nRefactoring, Improvements, and Tooling\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n* migrate changed integration tests to isolated temp git repos and add an environment variable to override buildroot\n  `RB #4295 <https://rbcommons.com/s/twitter/r/4295>`_\n\n1.2.0rc1 (10/13/2016)\n---------------------\n\nSecond release candidate for stable 1.2.0.\n\nAPI Changes\n~~~~~~~~~~~\n\n* Add subsystem_utils to test_infra\n  `RB #4303 <https://rbcommons.com/s/twitter/r/4303>`_\n\nBugfixes\n~~~~~~~~\n\n* Switch default deference back to True for tarball artifact\n  `RB #4304 <https://rbcommons.com/s/twitter/r/4304>`_\n\n* Filter inactive goals from `Goal.all`.\n  `RB #4298 <https://rbcommons.com/s/twitter/r/4298>`_\n\n* JUnit runner fix for len(args) > max_args in argfile.safe_args\n  `RB #4294 <https://rbcommons.com/s/twitter/r/4294>`_\n\nRefactoring, Improvements, and Tooling\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n* Version clarification\n  `RB #4299 <https://rbcommons.com/s/twitter/r/4299>`_\n\n1.2.0rc0 (10/07/2016)\n---------------------\n\nFirst release candidate for stable 1.2.0.\n\nNew Features\n~~~~~~~~~~~~\n\n* Make the name= target keyword optional in BUILD files.\n  `RB #4275 <https://rbcommons.com/s/twitter/r/4275>`_\n\n* Add Scalafmt Support to Pants\n  `RB #4216 <https://rbcommons.com/s/twitter/r/4216>`_\n\nRefactoring, Improvements, and Tooling\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n* Add libffi to pants pre-reqs, qualify JDK req.\n  `RB #4285 <https://rbcommons.com/s/twitter/r/4285>`_\n\n* Update the setup.py description.\n  `RB #4283 <https://rbcommons.com/s/twitter/r/4283>`_\n\n* Refactor Intermediate Target Generation Logic\n  `RB #4277 <https://rbcommons.com/s/twitter/r/4277>`_\n\n* Clean up after failed artifact extractions\n  `RB #4255 <https://rbcommons.com/s/twitter/r/4255>`_\n\n* Publish the CPP plugin\n  `RB #4282 <https://rbcommons.com/s/twitter/r/4282>`_\n\n* Change --no-dryrun to the new flag in docs\n  `RB #4280 <https://rbcommons.com/s/twitter/r/4280>`_\n\n* Add --no-transitive flag to findbugs so you can run findbugs only for the targets specified on the command line\n  `RB #4276 <https://rbcommons.com/s/twitter/r/4276>`_\n\nNew Engine Work\n~~~~~~~~~~~~~~~\n\n* [engine] Rule Graph construction perf improvements\n  `RB #4281 <https://rbcommons.com/s/twitter/r/4281>`_\n\n* [engine] Introduce static analysis model and replace validator with it\n  `RB #4251 <https://rbcommons.com/s/twitter/r/4251>`_\n',
    'name': 'pantsbuild.pants.contrib.scrooge',
    'namespace_packages': ['pants', 'pants.contrib'],
    'package_data': {   },
    'package_dir': {   '': 'src'},
    'packages': [   'pants',
                    'pants.contrib',
                    'pants.contrib.scrooge',
                    'pants.contrib.scrooge.tasks'],
    'url': 'https://github.com/pantsbuild/pants',
    'version': '1.2.0rc2',
    'zip_safe': True}
)
